<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class AvaliacaoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function getAvaliacoes(
        int $nrOrg,
        int $nrParcExec
    ): array {
        $sql = <<<SQL
            SELECT
                PART.NRPARTICIPAVAL,
                AG.NRAVALIACAO,
                AG.NMAVALIACAO,
                AG.NRTIPOAVALIACAO,
                AG.NRPADRAVALIACAO,
                TO_CHAR(AG.DTINIREALIZAVAL, 'DD/MM/YYYY') DTINIREALIZAVAL,
                TO_CHAR(AG.DTFIMREALIZAVAL, 'DD/MM/YYYY') DTFIMREALIZAVAL,
                TA.NMTIPOAVALIACAO,
                PA.NMPADRAVALIACAO,
                PART.NRPARCAVALIADO,
                PART.NRPARCEXECAVAL,
                PART.NRCOMBQUESTAVAL,
                PART.IDSITUACAOAVAL,
                INITCAP(PART.IDSITUACAOAVAL) DSSITUACAOAVAL,
                PN_EXEC.NMPRINCIPALPARC NMPARCEXECAVAL,
                PN_PART.NMPRINCIPALPARC NMPARCAVALIADO
            FROM
                AVALIACAOGERAL AG
                JOIN
                PARTICIPAVAL PART ON
                    PART.NRORG = AG.NRORG AND
                    PART.NRAVALIACAO = AG.NRAVALIACAO
                LEFT JOIN
                TIPOAVALIACAO TA ON
                    TA.NRORG = AG.NRORG AND
                    TA.NRTIPOAVALIACAO = AG.NRTIPOAVALIACAO
                LEFT JOIN
                PADRAVALIACAO PA ON
                    PA.NRORG = AG.NRORG AND
                    PA.NRPADRAVALIACAO = AG.NRPADRAVALIACAO
                LEFT JOIN
                PARCNEGOCIO PN_EXEC ON
                    PN_EXEC.NRORG = PART.NRORG AND
                    PN_EXEC.NRPARCNEGOCIO = PART.NRPARCEXECAVAL
                LEFT JOIN
                PARCNEGOCIO PN_PART ON
                    PN_PART.NRORG = PART.NRORG AND
                    PN_PART.NRPARCNEGOCIO = PART.NRPARCAVALIADO
            WHERE
                AG.DTINIREALIZAVAL <= SYSDATE AND
                AG.DTFIMREALIZAVAL >= SYSDATE AND
                AG.IDATIVO = 'S' AND
                AG.NRORG = :P_NRORG AND
                AG.IDSITUACAOAVALIACAO != 'CONCLUIDA' AND
                PART.NRPARCEXECAVAL = :P_NRPARCEXEC
            ORDER BY
                (
                    CASE PART.IDSITUACAOAVAL
                        WHEN 'ANDAMENTO' THEN 1
                        WHEN 'PENDENTE' THEN 2
                        WHEN 'CONCLUIDA' THEN 3
                        ELSE 4
                    END
                ) ASC,
                PART.DTCONCLUSAOAVAL DESC,
                AG.DTFIMREALIZAVAL ASC,
                AG.DTINIREALIZAVAL ASC,
                AG.NMAVALIACAO ASC
SQL;

        $params = [
            'P_NRORG'   => $nrOrg,
            'P_NRPARCEXEC' => $nrParcExec,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $avaliacoes = $std->fetchAll();

        return $avaliacoes;
    }

    public function getQuestoesAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            SELECT
                (NRORDEQUESTAVAL || '- ' || Q.TXQUESTAO) DSQUESTAO,
                Q.*,
                EA.NREXECAVALIACAO,
                TA.NRTEMAANALISE,
                TA.NMTEMAANALISE,
                CR.NRCRITERIORESUL,
                CR.NMCRITERIORESUL,
                CQ.NRCOMBQUESTAVAL,
                CQ.NMCOMBQUESTAVAL,
                AG.NRAGRUPQUESTAVA,
                AG.NMAGRUPQUESTAVA,
                AG.TXAGRUPQUESTAVA,
                NIVEL.NRNIVELQUESTAO,
                NIVEL.NMNIVELQUESTAO,
                RA.TXRESPAVALIACAO,
                RA.NRRESPOSTA
            FROM
                QUESTAVALIACAO QA
                JOIN
                QUESTAO Q ON
                    Q.NRORG = QA.NRORG AND
                    Q.NRQUESTAO = QA.NRQUESTAO AND
                    Q.IDTIPOQUESTAO = 'FECHADA' AND
                    Q.IDATIVO = 'S'
                JOIN
                EXECAVALIACAO EA ON
                    EA.NRORG = QA.NRORG AND
                    EA.NRQUESTAO = QA.NRQUESTAO AND
                    EA.NRAVALIACAO = QA.NRAVALIACAO AND
                    EA.NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL AND
                    EA.NRPARCEXECAVAL = :P_NRPARCEXECAVAL AND
                    EA.NRPARCAVALIADO = :P_NRPARCAVALIADO
                LEFT JOIN
                AVL_TEMAANALISE TA ON
                    TA.NRORG = QA.NRORG AND
                    TA.NRTEMAANALISE = QA.NRTEMAANALISE
                LEFT JOIN
                CRITERIORESULT CR ON
                    CR.NRORG = QA.NRORG AND
                    CR.NRCRITERIORESUL = QA.NRCRITERIORESUL
                LEFT JOIN
                COMBQUESTAVAL CQ ON
                    CQ.NRORG = QA.NRORG AND
                    CQ.NRCOMBQUESTAVAL = QA.NRCOMBQUESTAVAL
                LEFT JOIN
                AGRUPQUESTAVAL AG ON
                    AG.NRORG = QA.NRORG AND
                    AG.NRAGRUPQUESTAVA = QA.NRAGRUPQUESTAVA
                LEFT JOIN
                NIVELQUESTAO NIVEL ON
                    NIVEL.NRORG = QA.NRORG AND
                    NIVEL.NRNIVELQUESTAO = QA.NRNIVELQUESTAO
                LEFT JOIN
                RESPAVALIACAO RA ON
                    RA.NRORG = EA.NRORG AND
                    RA.NREXECAVALIACAO = EA.NREXECAVALIACAO AND
                    RA.IDATIVO = 'S'
            WHERE
                QA.NRORG = :P_NRORG AND
                QA.NRAVALIACAO = :P_NRAVALIACAO
            ORDER BY
                NRORDEQUESTAVAL ASC
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $questoes = $std->fetchAll();

        return $questoes;
    }

    public function getRespostasQuestao(
        int $nrOrg,
        int $nrQuestao
    ): array {
        $sql = <<<SQL
            SELECT
                R.NRQUESTAO,
                R.NRRESPOSTA,
                R.DSRESPOSTA,
                R.NRORG
            FROM
                QUESTAO Q
                JOIN
                RESPOSTA R ON
                    Q.NRQUESTAO = R.NRQUESTAO AND
                    Q.NRORG = R.NRORG
            WHERE
                Q.NRORG = :P_NRORG AND
                Q.NRQUESTAO = :P_NRQUESTAO
            ORDER BY
                R.NRRESPOSTA ASC
SQL;

        $params = [
            'P_NRORG'   => $nrOrg,
            'P_NRQUESTAO' => $nrQuestao,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $respostas = $std->fetchAll();

        return $respostas;
    }

    public function getQuestao(
        int $nrOrg,
        int $nrQuestao
    ) {
        $sql = <<<SQL
            SELECT
                NRQUESTAO,
                NRNIVELPADQUEST,
                TXQUESTAO,
                IDTIPOQUESTAO,
                DTREVISAQUESTAO,
                IDQUESTAOOBRIGA,
                IDOPCAORESPOSTA,
                NRORG,
                IDATIVO
            FROM
                QUESTAO
            WHERE
                NRORG = :P_NRORG AND
                NRQUESTAO = :P_NRQUESTAO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRQUESTAO' => $nrQuestao,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $questao = $std->fetch();

        return $questao;
    }

    public function getResposta(
        int $nrOrg,
        int $nrResposta
    ) {
        $sql = <<<SQL
            SELECT
                NRRESPOSTA,
                NRORG,
                NRQUESTAO,
                DSRESPOSTA,
                IDRESPOSCORRETA,
                VRPESORESPOSTA,
                NRORDENARESPOST,
                IDATIVO
            FROM
                RESPOSTA
            WHERE
                NRORG = :P_NRORG AND
                NRRESPOSTA = :P_NRRESPOSTA
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRRESPOSTA' => $nrResposta,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $resposta = $std->fetch();

        return $resposta;
    }

    public function getExecAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            SELECT
                NREXECAVALIACAO,
                NRORG,
                NRAVALIACAO,
                NRPARCAVALIADO,
                NRPARCEXECAVAL,
                NRQUESTAO,
                NRCOMBQUESTAVAL,
                DTEXECUCAOAVAL,
                IDATIVO
            FROM
                EXECAVALIACAO
            WHERE
                NRORG = :P_NRORG AND
                NRAVALIACAO = :P_NRAVALIACAO AND
                NRPARCEXECAVAL = :P_NRPARCEXECAVAL AND
                NRPARCAVALIADO = :P_NRPARCAVALIADO AND
                NRQUESTAO = :P_NRQUESTAO AND
                NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $execAvaliacao = $std->fetch();

        return $execAvaliacao;
    }

    public function getRespAvaliacao(
        int $nrOrg,
        int $nrExecAvaliacao
    ) {
        $sql = <<<SQL
            SELECT
                NRRESPAVALIACAO,
                NRORG,
                NREXECAVALIACAO,
                NRRESPOSTA,
                TXRESPAVALIACAO,
                DTRESPAVALIACAO,
                VRRESPAVALIACAO,
                TXOBSCORRECAVAL,
                VRNOTARESPAVAL,
                IDATIVO
            FROM
                RESPAVALIACAO
            WHERE
                NRORG = :P_NRORG AND
                NREXECAVALIACAO = :P_NREXECAVALIACAO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NREXECAVALIACAO' => $nrExecAvaliacao,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $respAvaliacao = $std->fetch();

        return $respAvaliacao;
    }

    public function updateRespAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE RESPAVALIACAO
            SET
                NRRESPOSTA = :P_NRRESPOSTA,
                TXRESPAVALIACAO = :P_DSRESPOSTA,
                CDOPERULTATU = :P_CDOPERADOR,
                NRORGULTATU = :P_NRORG,
                DTULTATU = SYSDATE
            WHERE
                NRORG = :P_NRORG AND
                NRRESPAVALIACAO = :P_NRRESPAVALIACAO
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insertRespAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO RESPAVALIACAO (
                NRRESPAVALIACAO,    NRORG,              NREXECAVALIACAO,
                NRRESPOSTA,         TXRESPAVALIACAO,    DTRESPAVALIACAO,
                VRRESPAVALIACAO,    TXOBSCORRECAVAL,    VRNOTARESPAVAL,
                IDATIVO,            DTINCLUSAO,         DTULTATU,
                NRORGINCLUSAO,      CDOPERINCLUSAO,     NRORGULTATU,
                CDOPERULTATU
            )
            VALUES (
                :NRRESPAVALIACAO,   :NRORG,             :NREXECAVALIACAO,
                :NRRESPOSTA,        :DSRESPOSTA,   SYSDATE,
                NULL,               '',                 NULL,
                'S',                SYSDATE,            SYSDATE,
                :NRORG,             :CDOPERADOR,        :NRORG,
                :CDOPERADOR
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function updateParticipAval(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE PARTICIPAVAL
            SET
                IDSITUACAOAVAL  = 'ANDAMENTO',
                DTULTATU = SYSDATE,
                NRORGULTATU = :P_NRORG,
                CDOPERULTATU = :P_CDOPERADOR
            WHERE
                NRAVALIACAO     = :P_NRAVALIACAO AND
                NRPARCEXECAVAL  = :P_NRPARCEXECAVAL AND
                NRPARCAVALIADO  = :P_NRPARCAVALIADO AND
                NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL AND
                NRORG           = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function updateExecAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE EXECAVALIACAO
            SET
                DTEXECUCAOAVAL  = SYSDATE,
                DTULTATU = SYSDATE,
                NRORGULTATU = :P_NRORG,
                CDOPERULTATU = :P_CDOPERADOR
            WHERE
                NRAVALIACAO     = :P_NRAVALIACAO AND
                NRPARCEXECAVAL  = :P_NRPARCEXECAVAL AND
                NRPARCAVALIADO  = :P_NRPARCAVALIADO AND
                NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL AND
                NRORG           = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function concluirAvaliacao(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE PARTICIPAVAL
            SET
                IDSITUACAOAVAL  = 'CONCLUIDA',
                DTCONCLUSAOAVAL = SYSDATE,
                DTULTATU = SYSDATE,
                NRORGULTATU = :P_NRORG,
                CDOPERULTATU = :P_CDOPERADOR
            WHERE
                NRAVALIACAO     = :P_NRAVALIACAO AND
                NRPARCEXECAVAL  = :P_NRPARCEXECAVAL AND
                NRPARCAVALIADO  = :P_NRPARCAVALIADO AND
                NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL AND
                NRORG           = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getParticipAval(
        int $nrOrg,
        int $nrParcticipAval
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                PARTICIPAVAL
            WHERE
                NRORG = :P_NRORG AND
                NRPARTICIPAVAL = :P_NRPARTICIPAVAL
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARTICIPAVAL' => $nrParcticipAval,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $participAval = $std->fetch();

        return $participAval;
    }
}
